while True: 
     name = input('Введите имя:')
     age = int(input('Введите возраст:'))
     if age < 18: 
           print ("Привет {}".format(name), 'тебе до 18 осталось', (18-int(age)),'лет' )
     elif age >= 18:
        print (f"Привет {name}", 'ты старше 18' )


from setuptools import setup, find_packages


setup(
    name='julie-project',
    version='0.1',
    author="Julie",
    author_email='email@example.com',
    packages=find_packages(),
    url='https://github.com/JulieYatskevich/DZ-4',
    install_requires=[
          'Django==4.0.4',
      ],

)